@@ -4,8 +4,6 @@ import (
 	"bytes"
 	"io"
 	"net/url"
-
-	yaml "gopkg.in/yaml.v3"
 )
 
 type uriDecoder struct {
@@ -50,11 +48,5 @@ func (dec *uriDecoder) Decode() (*CandidateNode, error) {
 		return nil, err
 	}
 	dec.readAnything = true
-	return &CandidateNode{
-		Node: &yaml.Node{
-			Kind:  yaml.ScalarNode,
-			Tag:   "!!str",
-			Value: newValue,
-		},
-	}, nil
+	return createStringScalarNode(newValue), nil
 }
