@@ -60,7 +60,7 @@ var envOperatorScenarios = []expressionScenario{
 		environmentVariables: map[string]string{"pathEnv": ".a.b[0].name", "valueEnv": "moo"},
 		expression:           `eval(strenv(pathEnv)) = strenv(valueEnv)`,
 		expected: []string{
-			"D0, P[], (doc)::{a: {b: [{name: moo}, {name: cat}]}}\n",
+			"D0, P[], (!!map)::{a: {b: [{name: moo}, {name: cat}]}}\n",
 		},
 	},
 	{
@@ -136,7 +136,7 @@ var envOperatorScenarios = []expressionScenario{
 		document:             "{v: \"${myenv}\"}",
 		expression:           `.v |= envsubst`,
 		expected: []string{
-			"D0, P[], (doc)::{v: \"cat meow\"}\n",
+			"D0, P[], (!!map)::{v: \"cat meow\"}\n",
 		},
 	},
 	{
@@ -150,6 +150,16 @@ var envOperatorScenarios = []expressionScenario{
 		expression:    `"the ${notThere} ${alsoNotThere}" | envsubst(nu,ff)`,
 		expectedError: "variable ${notThere} not set",
 	},
+	{
+		description:          "with header/footer",
+		skipDoc:              true,
+		environmentVariables: map[string]string{"myenv": "cat meow"},
+		document:             "# abc\n{v: \"${myenv}\"}\n# xyz\n",
+		expression:           `(.. | select(tag == "!!str")) |= envsubst`,
+		expected: []string{
+			"D0, P[], (!!map)::# abc\n{v: \"cat meow\"}\n# xyz\n",
+		},
+	},
 }
 
 func TestEnvOperatorScenarios(t *testing.T) {
