@@ -7,10 +7,124 @@ import (
 	"strings"
 )
 
+var StringInterpolationEnabled = true
+
 type changeCasePrefs struct {
 	ToUpperCase bool
 }
 
+func encodeToYamlString(node *CandidateNode) (string, error) {
+	encoderPrefs := encoderPreferences{
+		format: YamlFormat,
+		indent: ConfiguredYamlPreferences.Indent,
+	}
+	result, err := encodeToString(node, encoderPrefs)
+
+	if err != nil {
+		return "", err
+	}
+	return chomper.ReplaceAllString(result, ""), nil
+}
+
+func evaluate(d *dataTreeNavigator, context Context, expStr string) (string, error) {
+	exp, err := ExpressionParser.ParseExpression(expStr)
+	if err != nil {
+		return "", err
+	}
+	result, err := d.GetMatchingNodes(context, exp)
+	if err != nil {
+		return "", err
+	}
+	if result.MatchingNodes.Len() == 0 {
+		return "", nil
+	}
+	node := result.MatchingNodes.Front().Value.(*CandidateNode)
+	if node.Kind != ScalarNode {
+		return encodeToYamlString(node)
+	}
+	return node.Value, nil
+}
+
+func interpolate(d *dataTreeNavigator, context Context, str string) (string, error) {
+	var sb strings.Builder
+	var expSb strings.Builder
+	inExpression := false
+	nestedBracketsCounter := 0
+	runes := []rune(str)
+	for i := 0; i < len(runes); i++ {
+		char := runes[i]
+		if !inExpression {
+			if char == '\\' && i != len(runes)-1 && runes[i+1] == '(' {
+				inExpression = true
+				i = i + 1 // skip over the next open bracket
+				continue
+			}
+			sb.WriteRune(char)
+		} else { // we are in an expression
+			if char == ')' && nestedBracketsCounter == 0 {
+				// finished the expression!
+				log.Debugf("Expression is :%v", expSb.String())
+				value, err := evaluate(d, context, expSb.String())
+				if err != nil {
+					return "", err
+				}
+
+				inExpression = false
+				expSb = strings.Builder{} // reset this
+
+				sb.WriteString(value)
+				continue
+			} else if char == '(' {
+				nestedBracketsCounter++
+			} else if char == '\\' && i != len(runes)-1 && runes[i+1] == ')' {
+				// close brackets is escaped, skip over it
+				expSb.WriteRune(char)
+				expSb.WriteRune(runes[i+1])
+				i = i + 1
+				continue
+			} else if char == ')' {
+				nestedBracketsCounter--
+			}
+			expSb.WriteRune(char)
+		}
+
+	}
+	if inExpression {
+		return "", fmt.Errorf("unclosed interpolation string \\(")
+	}
+	return sb.String(), nil
+}
+
+func stringInterpolationOperator(d *dataTreeNavigator, context Context, expressionNode *ExpressionNode) (Context, error) {
+	if !StringInterpolationEnabled {
+		return context.SingleChildContext(
+			createScalarNode(expressionNode.Operation.StringValue, expressionNode.Operation.StringValue),
+		), nil
+	}
+	if context.MatchingNodes.Len() == 0 {
+		value, err := interpolate(d, context, expressionNode.Operation.StringValue)
+		if err != nil {
+			return Context{}, err
+		}
+		node := createScalarNode(value, value)
+		return context.SingleChildContext(node), nil
+	}
+
+	var results = list.New()
+
+	for el := context.MatchingNodes.Front(); el != nil; el = el.Next() {
+		candidate := el.Value.(*CandidateNode)
+		value, err := interpolate(d, context.SingleChildContext(candidate), expressionNode.Operation.StringValue)
+		if err != nil {
+			return Context{}, err
+		}
+		node := createScalarNode(value, value)
+		results.PushBack(node)
+	}
+
+	return context.ChildContext(results), nil
+}
+
 func trimSpaceOperator(_ *dataTreeNavigator, context Context, _ *ExpressionNode) (Context, error) {
 	results := list.New()
 	for el := context.MatchingNodes.Front(); el != nil; el = el.Next() {
@@ -29,6 +143,31 @@ func trimSpaceOperator(_ *dataTreeNavigator, context Context, _ *ExpressionNode)
 	return context.ChildContext(results), nil
 }
 
+func toStringOperator(_ *dataTreeNavigator, context Context, _ *ExpressionNode) (Context, error) {
+	results := list.New()
+	for el := context.MatchingNodes.Front(); el != nil; el = el.Next() {
+		node := el.Value.(*CandidateNode)
+		var newStringNode *CandidateNode
+		if node.Tag == "!!str" {
+			newStringNode = node.CreateReplacement(ScalarNode, "!!str", node.Value)
+		} else if node.Kind == ScalarNode {
+			newStringNode = node.CreateReplacement(ScalarNode, "!!str", node.Value)
+			newStringNode.Style = DoubleQuotedStyle
+		} else {
+			result, err := encodeToYamlString(node)
+			if err != nil {
+				return Context{}, err
+			}
+			newStringNode = node.CreateReplacement(ScalarNode, "!!str", result)
+			newStringNode.Style = DoubleQuotedStyle
+		}
+		newStringNode.Tag = "!!str"
+		results.PushBack(newStringNode)
+	}
+
+	return context.ChildContext(results), nil
+}
+
 func changeCaseOperator(_ *dataTreeNavigator, context Context, expressionNode *ExpressionNode) (Context, error) {
 	results := list.New()
 	prefs := expressionNode.Operation.Preferences.(changeCasePrefs)
