@@ -5,6 +5,64 @@ import (
 )
 
 var stringsOperatorScenarios = []expressionScenario{
+	{
+		description: "Interpolation",
+		document:    "value: things\nanother: stuff",
+		expression:  `.message = "I like \(.value) and \(.another)"`,
+		expected: []string{
+			"D0, P[], (!!map)::value: things\nanother: stuff\nmessage: I like things and stuff\n",
+		},
+	},
+	{
+		description: "Interpolation - not a string",
+		document:    `value: {an: apple}`,
+		expression:  `.message = "I like \(.value)"`,
+		expected: []string{
+			"D0, P[], (!!map)::value: {an: apple}\nmessage: 'I like {an: apple}'\n",
+		},
+	},
+	{
+		skipDoc:     true,
+		description: "Interpolation - just escape",
+		expression:  `"\\"`,
+		expected: []string{
+			"D0, P[], (!!str)::\\\\\n",
+		},
+	},
+	{
+		skipDoc:     true,
+		description: "Interpolation - nested",
+		document:    `value: things`,
+		expression:  `"Hi \( (.value) )"`,
+		expected: []string{
+			"D0, P[], (!!str)::Hi things\n",
+		},
+	},
+	{
+		skipDoc:     true,
+		description: "Interpolation - don't",
+		document:    `value: things`,
+		expression:  `"Hi (.value)"`,
+		expected: []string{
+			"D0, P[], (!!str)::Hi (.value)\n",
+		},
+	},
+	{
+		skipDoc:     true,
+		description: "Interpolation - random close bracket",
+		document:    `value: things`,
+		expression:  `"Hi )"`,
+		expected: []string{
+			"D0, P[], (!!str)::Hi )\n",
+		},
+	},
+	{
+		skipDoc:       true,
+		description:   "Interpolation - unclosed interpolation string",
+		document:      `value: things`,
+		expression:    `"Hi \("`,
+		expectedError: "unclosed interpolation string \\(",
+	},
 	{
 		description:    "To up (upper) case",
 		subdescription: "Works with unicode characters",
@@ -267,6 +325,15 @@ var stringsOperatorScenarios = []expressionScenario{
 		expression: `split("; ")`,
 		expected:   []string{},
 	},
+	{
+		description:    "To string",
+		subdescription: "Note that you may want to force `yq` to leave scalar values wrapped by passing in `--unwrapScalar=false` or `-r=f`",
+		document:       `[1, true, null, ~, cat, {an: object}, [array, 2]]`,
+		expression:     ".[] |= to_string",
+		expected: []string{
+			"D0, P[], (!!seq)::[\"1\", \"true\", \"null\", \"~\", cat, \"{an: object}\", \"[array, 2]\"]\n",
+		},
+	},
 }
 
 func TestStringsOperatorScenarios(t *testing.T) {
